"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MyStromSwitchAccessory = void 0;
const dingzDaBaseAccessory_1 = require("./lib/dingzDaBaseAccessory");
/**
 * Switch Platform Accessory
 * An instance of this class is created for each accessory your platform registers
 * Each accessory may expose multiple services of different service types.
 * TODO: Implement Switch Zero in this class
 */
class MyStromSwitchAccessory extends dingzDaBaseAccessory_1.DingzDaBaseAccessory {
    constructor(_platform, _accessory) {
        var _a, _b, _c, _d;
        super(_platform, _accessory);
        this._platform = _platform;
        this._accessory = _accessory;
        this.temperatureService = undefined;
        this.outletState = {
            relay: false,
            temperature: 0,
            power: 0,
        };
        // Set Base URL
        this.mystromDeviceInfo = this.device.hwInfo;
        this.log.debug('Setting informationService Characteristics ->', this.device.model);
        this.accessory
            .getService(this.platform.Service.AccessoryInformation)
            .setCharacteristic(this.platform.Characteristic.Manufacturer, 'MyStrom AG')
            .setCharacteristic(this.platform.Characteristic.AppMatchingIdentifier, 'ch.mystrom.iOSApp')
            .setCharacteristic(this.platform.Characteristic.Model, `MyStrom WiFi Switch ${this.device.model}`)
            .setCharacteristic(this.platform.Characteristic.FirmwareRevision, (_a = this.mystromDeviceInfo.version) !== null && _a !== void 0 ? _a : 'N/A')
            .setCharacteristic(this.platform.Characteristic.HardwareRevision, this.device.model)
            .setCharacteristic(this.platform.Characteristic.SerialNumber, this.device.mac);
        this.outletService =
            (_b = this.accessory.getService(this.platform.Service.Outlet)) !== null && _b !== void 0 ? _b : this.accessory.addService(this.platform.Service.Outlet);
        this.outletService.setCharacteristic(this.platform.Characteristic.Name, (_c = this.device.name) !== null && _c !== void 0 ? _c : `${this.accessory.context.device.model} Outlet`);
        // register handlers for the On/Off Characteristic
        this.outletService
            .getCharacteristic(this.platform.Characteristic.On)
            .on("set" /* CharacteristicEventTypes.SET */, this.setOn.bind(this)) // SET - bind to the `setOn` method below
            .on("get" /* CharacteristicEventTypes.GET */, this.getOn.bind(this)); // GET - bind to the `getOn` method below
        this.outletService
            .getCharacteristic(this.platform.Characteristic.OutletInUse)
            .on("get" /* CharacteristicEventTypes.GET */, this.getOutletInUse.bind(this)); // GET - bind to the `getOn` method below
        // Only EU and CH v2 Switches have temperature sensor
        if (this.device.model !== 'Zero' &&
            this.device.model !== 'CH v1' &&
            this.device.model !== undefined) {
            // Switch has a temperature sensor, make it available here
            this.temperatureService =
                (_d = this.accessory.getService(this.platform.Service.TemperatureSensor)) !== null && _d !== void 0 ? _d : this.accessory.addService(this.platform.Service.TemperatureSensor);
            this.temperatureService.setCharacteristic(this.platform.Characteristic.Name, 'Temperature');
            // create handlers for required characteristics
            this.temperatureService
                .getCharacteristic(this.platform.Characteristic.CurrentTemperature)
                .on("get" /* CharacteristicEventTypes.GET */, this.getTemperature.bind(this));
        }
        else {
            // Make sure spurious temperature services (e.g. from Zero and CH v1) don't remain in the system
            const temperatureService = this.accessory.getService(this.platform.Service.TemperatureSensor);
            if (temperatureService !== undefined) {
                this.platform.log.warn('Removing spurious temperature service');
                this.accessory.removeService(temperatureService);
            }
        }
    }
    identify() {
        this.log.debug('Identify! -> Who am I? I am', this.accessory.displayName);
    }
    // Get updated device info and update the corresponding values
    getDeviceStateUpdate() {
        return this.getDeviceReport()
            .then((report) => {
            var _a;
            // push the new value to HomeKit
            this.outletState = report;
            this.outletService
                .getCharacteristic(this.platform.Characteristic.On)
                .updateValue(this.outletState.relay);
            switch ((_a = this.device.model) !== null && _a !== void 0 ? _a : 'unknown') {
                case 'CH v1':
                case 'Zero':
                    this.outletService
                        .getCharacteristic(this.platform.Characteristic.OutletInUse)
                        .updateValue(this.outletState.relay);
                    break;
                default:
                    this.outletService
                        .getCharacteristic(this.platform.Characteristic.OutletInUse)
                        .updateValue(this.outletState.power > 0);
                    break;
            }
            if (this.temperatureService &&
                this.outletState.temperature !== null &&
                this.outletState.temperature !== undefined) {
                this.temperatureService
                    .getCharacteristic(this.platform.Characteristic.CurrentTemperature)
                    .updateValue(this.outletState.temperature);
            }
            return Promise.resolve();
        })
            .catch((e) => {
            return Promise.reject(e);
        });
    }
    setOn(value, callback) {
        this.log.debug('Set Characteristic On ->', value);
        this.outletState.relay = value;
        this.setDeviceState(callback);
    }
    getOn(callback) {
        var _a;
        const isOn = (_a = this.outletState) === null || _a === void 0 ? void 0 : _a.relay;
        this.log.debug('Get Characteristic On ->', isOn);
        callback(this.reachabilityState, isOn);
    }
    getTemperature(callback) {
        var _a;
        const temperature = (_a = this.outletState) === null || _a === void 0 ? void 0 : _a.temperature;
        this.log.debug('Get Characteristic Temperature ->', temperature, '° C');
        // Don't return a value if temperature is not defined
        if (temperature !== null && temperature !== undefined) {
            callback(this.reachabilityState, temperature);
        }
        else {
            callback(new Error('No valid temperature value'));
        }
    }
    getOutletInUse(callback) {
        var _a, _b;
        const inUse = this.device.model === 'Zero' // Zero does not measure power
            ? (_a = this.outletState) === null || _a === void 0 ? void 0 : _a.relay
            : ((_b = this.outletState) === null || _b === void 0 ? void 0 : _b.power) > 0;
        this.log.debug('Get Characteristic OutletInUse ->', inUse);
        callback(this.reachabilityState, inUse);
    }
    setDeviceState(callback) {
        const relayUrl = `${this.baseUrl}/relay?state=${this.outletState.relay ? '1' : '0'}`;
        this.request
            .get(relayUrl)
            .catch(this.handleRequestErrors.bind(this))
            .finally(() => {
            callback(this.reachabilityState);
        });
    }
    async getDeviceReport() {
        const reportUrl = `${this.baseUrl}/report`;
        return await this.request.get(reportUrl).then((response) => {
            return response.data;
        });
    }
}
exports.MyStromSwitchAccessory = MyStromSwitchAccessory;
//# sourceMappingURL=myStromSwitchAccessory.js.map